@@ -9,6 +9,7 @@ mod nums;
 mod op;
 mod run;
 mod session;
+mod shell;
 mod state;
 mod term;
 
@@ -39,6 +40,9 @@ fn main() -> Result<(), errors::FxError> {
                     eprintln!("{}", e);
                 }
             }
+            "--init" => {
+                print!("{}", shell::INTEGRATION_CODE);
+            }
             _ => {
                 if let Err(e) = run::run(PathBuf::from(&args[1]), false) {
                     eprintln!("{}", e);
