@@ -46,6 +46,8 @@ pub struct State {
     pub list: Vec<ItemInfo>,
     pub current_dir: PathBuf,
     pub trash_dir: PathBuf,
+    pub lwd_file: Option<PathBuf>,
+    pub match_vim_exit_behavior: bool,
     pub default: String,
     pub commands: Option<BTreeMap<String, String>>,
     pub registers: Registers,
@@ -258,6 +260,8 @@ impl State {
             },
             current_dir: PathBuf::new(),
             trash_dir: PathBuf::new(),
+            lwd_file: None,
+            match_vim_exit_behavior: config.match_vim_exit_behavior.unwrap_or_default(),
             default: config
                 .default
                 .unwrap_or_else(|| env::var("EDITOR").unwrap_or_default()),
